HttpApiRequest class

Inheritance
Available extensions

Constructors

HttpApiRequest({required Uri url, required String endpoint, required Map<String, dynamic> params, RequestContext? context, Map<String, String>? headers, ApiCodec? codec})
factory

Properties

codec → ApiCodec?
finalinherited
context → Map<String, dynamic>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
method → String
final
parameters → Map<String, dynamic>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri
final

Methods

apply(List<ApiProvider<ApiRequest>> providers) → FutureOr<ApiRequest>

Available on ApiRequest, provided by the RequestProvider extension

build() → Request
change({Map<String, String>? headers, Map<String, dynamic>? context, ApiCodec? codec}) → HttpApiRequest
override
decode<T>(dynamic value) → T
inherited
encode(dynamic value) → dynamic
inherited
get<T>(String key) → T
inherited
getOpt<T>(String key) → T?
inherited
invoke(Function handler) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

segment(String s) → String