WrappedEndpoint<T> class

Implemented types
Implementers

Properties

endpoint ↔ ApiEndpoint
getter/setter pair
fn ↔ EndpointHandler Function(EndpointHandler )
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(ApiBuilder builder) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited